==> nodejs_interop-0.5.0.tar.gz: lib/src/js/promise.dart <==
part of nodejs_interop.js;

/// Completes a [Promise] with a value or an error.
typedef void PromiseCompleter<T>(void resolve(T value), void reject(error));

/// An object representing a delayed computation.
///
/// A [Promise] is used to represent a potential value, or error, that will be available at some time in the future.
/// Receivers of a [Promise] can register callbacks that handle the value or error once it is available.
@JS('Promise')
class Promise<T> {

  /// Creates a new promise.
  external Promise(PromiseCompleter<T> completer);

  /// Wait for all the given [promises] to complete and collect their values.
  /// Returns a [Promise] which will resolve once all the [promises] have resolved.
  ///
  /// The value of the returned promise will be a [List] of all the values that were produced.
  ///
  /// If any of the given promises rejects, then the returned promise rejects with that error.
  /// If other promises reject, those errors are discarded.
  external static Promise<List<T>> all<T>(Iterable<Promise<T>> promises);

  /// Returns the result of the first [Promise] in [promises] to complete.
  ///
  /// The returned promise is completed with the result of the first promise in [promises] to report that it is complete.
  /// The results of all the other promises are discarded.
  ///
  /// If [promises] is empty, or if none of its promises complete, the returned promise never completes.
  external static Promise<T> race<T>(Iterable<Promise<T>> promises);

  /// Returns a [Promise] that is rejected with the given [error].
  external static Promise<T> reject<T>(error);

  /// Returns a [Promise] that is resolved with the given [value].
  external static Promise<T> resolve<T>(T value);

  /// Registers callbacks to be called when this promise completes.
  external Promise<U> then<U>(U onFulfilled(T value), [U onRejected(error)]);
}

==> nodejs_interop-0.8.0.tar.gz: lib/src/js/promise.dart <==
part of nodejs_interop.js;

/// Completes a [Promise] with a value or an error.
typedef void PromiseCompleter<T>(void resolve(T value), void reject(Object error));

/// An object representing a delayed computation.
///
/// A [Promise] is used to represent a potential value, or error, that will be available at some time in the future.
/// Receivers of a [Promise] can register callbacks that handle the value or error once it is available.
@JS('Promise')
class Promise<T> {

  /// Creates a new promise.
  external Promise(PromiseCompleter<T> completer);

  /// Wait for all the given [promises] to complete and collect their values.
  /// Returns a [Promise] which will resolve once all the [promises] have resolved.
  ///
  /// The value of the returned promise will be a [List] of all the values that were produced.
  ///
  /// If any of the given promises rejects, then the returned promise rejects with that error.
  /// If other promises reject, those errors are discarded.
  external static Promise<List<T>> all<T>(Iterable<Promise<T>> promises);

  /// Returns the result of the first [Promise] in [promises] to complete.
  ///
  /// The returned promise is completed with the result of the first promise in [promises] to report that it is complete.
  /// The results of all the other promises are discarded.
  ///
  /// If [promises] is empty, or if none of its promises complete, the returned promise never completes.
  external static Promise<T> race<T>(Iterable<Promise<T>> promises);

  /// Returns a [Promise] that is rejected with the given [error].
  external static Promise<T> reject<T>(Object error);

  /// Returns a [Promise] that is resolved with the given [value].
  external static Promise<T> resolve<T>(T value);

  /// Handles errors emitted by this promise.
  external Promise<T> JS$catch(onRejected(Object error)); // ignore: non_constant_identifier_names

  /// Registers callbacks to be called when this promise completes.
  external Promise<U> then<U>(U onFulfilled(T value), [onRejected(Object error)]);
}
